==> gconfmm2.0_2.0.2.orig.tar.gz: gconfmm-2.0.2/gconf/gconfmm/callback.h <==
// $Id: callback.h,v 1.3 2002/09/20 13:59:36 murrayc Exp $ -*- c++ -*-

/* callback.h
 *
 * Copyright (C) 2000-2002 GConfmm Development Team
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#ifndef GCONFMM_CALLBACK_H
#define GCONFMM_CALLBACK_H

extern "C"
{
#include <gconf/gconf-client.h>
}

#include <glibmm/object.h>
#include <gconfmm/entry.h>

namespace Gnome
{

namespace Conf
{

typedef SigC::Slot2<void, guint, Entry> Callback;

class Client;

#ifndef DOXYGEN_SHOULD_SKIP_THIS
class CallbackHolder
{
public:

  CallbackHolder(Callback slot);
  ~CallbackHolder();

  void add(Client* pObj);

  Callback m_Slot;

  static void destroy(void *data);
  static void call(GConfClient *client, guint i, GConfEntry *entry, void *data);  
};
#endif /* DOXYGEN_SHOULD_SKIP_THIS */

} /* namespace Conf */
} /* namespace Gnome */

#endif //GCONFMM_CALLBACK_H

==> gconfmm-2.5.1.tar.gz: gconfmm-2.5.1/gconf/gconfmm/callback.h <==
// $Id: callback.h,v 1.3 2002/09/20 13:59:36 murrayc Exp $ -*- c++ -*-

/* callback.h
 *
 * Copyright (C) 2000-2002 GConfmm Development Team
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#ifndef GCONFMM_CALLBACK_H
#define GCONFMM_CALLBACK_H

extern "C"
{
#include <gconf/gconf-client.h>
}

#include <glibmm/object.h>
#include <gconfmm/entry.h>

namespace Gnome
{

namespace Conf
{

typedef sigc::slot<void, guint, Entry> Callback;

class Client;

#ifndef DOXYGEN_SHOULD_SKIP_THIS
class CallbackHolder
{
public:

  CallbackHolder(Callback slot);
  ~CallbackHolder();

  void add(Client* pObj);

  Callback m_Slot;

  static void destroy(void *data);
  static void call(GConfClient *client, guint i, GConfEntry *entry, void *data);  
};
#endif /* DOXYGEN_SHOULD_SKIP_THIS */

} /* namespace Conf */
} /* namespace Gnome */

#endif //GCONFMM_CALLBACK_H
